@@ -57,6 +57,36 @@ def has_brew():
     return which("brew") is not None
 
 
+def ffmpeg_is_from_brew():
+    """
+    Is the used ffmpeg from Homebrew?
+    """
+    ffmpeg_path = which("ffmpeg")
+    if ffmpeg_path is None:
+        return False
+
+    return os.path.islink(ffmpeg_path) and "Cellar/ffmpeg" in os.readlink(ffmpeg_path)
+
+
+def get_default_model_path():
+    """
+    Return the default model path depending on whether the user is running Homebrew
+    or has a static build
+    """
+    if has_brew() and ffmpeg_is_from_brew():
+        # If the user installed ffmpeg using homebrew
+        return os.path.join(
+            # FIXME: change this once VMAF 2.0 is bundled with homebrew!
+            get_brewed_model_path(),
+            "vmaf_v0.6.1.pkl",
+        )
+    else:
+        # return the bundled file as a fallback
+        return os.path.join(
+            os.path.dirname(__file__), "vmaf_models", "vmaf_v0.6.1.json"
+        )
+
+
 def get_brewed_model_path():
     """
     Hack to get path for VMAF model from Linuxbrew
@@ -109,7 +139,7 @@ def get_framerate(input_file):
     try:
         match = pattern.search(str(output)).groups()[0]
         return float(match)
-    except Exception as e:
+    except Exception:
         print_error(f"could not parse FPS from file {input_file}!")
         sys.exit(1)
 
@@ -130,13 +160,14 @@ def get_framerates(ref, dist):
 def calc_vmaf(
     ref,
     dist,
-    model_path,
+    model_path=get_default_model_path(),
     scaling_algorithm="bicubic",
     phone_model=False,
     framerate=None,
     dry_run=False,
     verbose=False,
     threads=0,
+    n_threads=os.cpu_count(),
 ):
     vmaf_data = []
 
@@ -144,17 +175,15 @@ def calc_vmaf(
         print_error(f"Allowed scaling algorithms: {ALLOWED_SCALERS}")
         sys.exit(1)
 
+    temp_dir = tempfile.gettempdir()
+
+    temp_file_name_vmaf = os.path.join(
+        temp_dir, next(tempfile._get_candidate_names()) + "-vmaf.txt"
+    )
+
     try:
-        temp_dir = tempfile.gettempdir()
-
-        temp_file_name_vmaf = os.path.join(
-            temp_dir, next(tempfile._get_candidate_names()) + "-vmaf.txt"
-        )
-
         if verbose:
-            print_info(
-                f"Writing temporary VMAF information to: {temp_file_name_vmaf}"
-            )
+            print_info(f"Writing temporary VMAF information to: {temp_file_name_vmaf}")
 
         vmaf_opts = {
             "model_path": win_path_check(model_path),
@@ -164,6 +193,7 @@ def calc_vmaf(
             "psnr": "1",
             "ssim": "1",
             "ms_ssim": "1",
+            "n_threads": str(n_threads),
         }
 
         vmaf_opts_string = ":".join(f"{k}={v}" for k, v in vmaf_opts.items())
@@ -229,7 +259,13 @@ def get_ffmpeg_command(ref, dist, filter_chains=[], framerate=None, threads=0):
 
 
 def calc_ssim_psnr(
-    ref, dist, scaling_algorithm="bicubic", framerate=None, dry_run=False, verbose=False, threads=0
+    ref,
+    dist,
+    scaling_algorithm="bicubic",
+    framerate=None,
+    dry_run=False,
+    verbose=False,
+    threads=0,
 ):
     psnr_data = []
     ssim_data = []
@@ -238,23 +274,19 @@ def calc_ssim_psnr(
         print_error(f"Allowed scaling algorithms: {ALLOWED_SCALERS}")
         sys.exit(1)
 
+    temp_dir = tempfile.gettempdir()
+
+    temp_file_name_ssim = os.path.join(
+        temp_dir, next(tempfile._get_candidate_names()) + "-ssim.txt"
+    )
+    temp_file_name_psnr = os.path.join(
+        temp_dir, next(tempfile._get_candidate_names()) + "-psnr.txt"
+    )
+
     try:
-        temp_dir = tempfile.gettempdir()
-
-        temp_file_name_ssim = os.path.join(
-            temp_dir, next(tempfile._get_candidate_names()) + "-ssim.txt"
-        )
-        temp_file_name_psnr = os.path.join(
-            temp_dir, next(tempfile._get_candidate_names()) + "-psnr.txt"
-        )
-
         if verbose:
-            print_info(
-                f"Writing temporary SSIM information to: {temp_file_name_ssim}"
-            )
-            print_info(
-                f"Writing temporary PSNR information to: {temp_file_name_psnr}"
-            )
+            print_info(f"Writing temporary SSIM information to: {temp_file_name_ssim}")
+            print_info(f"Writing temporary PSNR information to: {temp_file_name_psnr}")
 
         filter_chains = [
             f"[1][0]scale2ref=flags={scaling_algorithm}[dist][ref]",
@@ -353,7 +385,15 @@ def main():
         action="store_true",
         help="Enable VMAF computation; calculates VMAF as well as SSIM and PSNR",
     )
-    parser.add_argument("-m", "--model-path", help="Set path to VMAF model file (.pkl)")
+
+    parser.add_argument(
+        "-m",
+        "--model-path",
+        type=str,
+        default=get_default_model_path(),
+        help="Use a specific VMAF model file.",
+    )
+
     parser.add_argument(
         "-p", "--phone-model", action="store_true", help="Enable VMAF phone model"
     )
@@ -378,10 +418,13 @@ def main():
         type=str,
         default="json",
         choices=["json", "csv"],
-        help="output in which format",
+        help="Output format for the metrics",
     )
     parser.add_argument(
-        "-r", "--framerate", type=float, help="force an input framerate",
+        "-r",
+        "--framerate",
+        type=float,
+        help="Force an input framerate",
     )
 
     parser.add_argument(
@@ -391,49 +434,38 @@ def main():
         default=0,
         help="Number of threads to do the calculations",
     )
-   
+
+    parser.add_argument(
+        "-nt",
+        "--n-threads",
+        type=int,
+        default=os.cpu_count(),
+        help="Set the value of libvmaf's n_threads option. "
+        "This determines the number of threads that are used for VMAF calculation",
+    )
 
     cli_args = parser.parse_args()
 
     ret = {}
 
     if cli_args.enable_vmaf:
-        if not cli_args.model_path:
-            if IS_WIN:
-                print_error(
-                    "Cannot not automatically determine VMAF model path under Windows. "
-                    "Please specify the --model-path manually."
-                )
-                sys.exit(1)
-            else:
-                if has_brew():
-                    model_path = os.path.join(
-                        get_brewed_model_path(), "vmaf_v0.6.1.pkl"
-                    )
-                else:
-                    print_error(
-                        "Could not automatically determine VMAF model path, since it was not installed using Homebrew. "
-                        "Please specify the --model-path manually or install ffmpeg with Homebrew."
-                    )
-                    sys.exit(1)
-        else:  # The model path was specified manually.
-            model_path = cli_args.model_path
-        if not os.path.isfile(model_path):
+        if not os.path.isfile(cli_args.model_path):
             print_error(
-                f"Could not find model at {model_path}. Please set --model-path to a valid VMAF .pkl file."
+                f"Could not find model at {cli_args.model_path}. Please set --model-path to a valid VMAF .pkl or .json model file."
             )
             sys.exit(1)
 
         ret["vmaf"] = calc_vmaf(
             cli_args.ref,
             cli_args.dist,
-            model_path,
+            cli_args.model_path,
             cli_args.scaling_algorithm,
             cli_args.phone_model,
             cli_args.framerate,
             cli_args.dry_run,
             cli_args.verbose,
             cli_args.threads,
+            cli_args.n_threads,
         )
 
     if not cli_args.disable_psnr_ssim:
@@ -445,7 +477,6 @@ def main():
             cli_args.dry_run,
             cli_args.verbose,
             cli_args.threads,
-
         )
         ret["psnr"] = ret_tmp["psnr"]
         ret["ssim"] = ret_tmp["ssim"]
